clear all
% create SPIDER traces from a .mat (pulse train) file
% Create your own pulse train for this program using make_pulse_train.m, or
% download one from frog.gatech.edu/code.html
%
% Authors: Justin Ratner and Michelle Rhodes
% Georgia Institute of Technology
% email: mrhodes3@gatech.edu
% March 2012; Last revision: 5/3/2013

freq_shift  = 9;     % SPIDER frequency shear, units 2*pi/(N*(temporal resolution))
delay       = 450;    

% load the pulse train file
directory = 'FULL PATH TO FOLDER THAT CONTAINS PULSE TRAINS';
filename = uigetfile(directory);
filepath = strcat(directory, filename);
load(filepath)
fprintf('Data file loaded... \n')
sz = size(et);
num_pulses = sz(1);
N = sz(2);      %number of points in each electric field

%add up the SPIDER traces for each pulse
et0 = et(1,:);
s0 = spider_trace(et0, freq_shift, delay);
s = s0;

if num_pulses > 1
    for k = 2:num_pulses
        s_curr = spider_trace(et(k, :), freq_shift, delay);
        s = s + s_curr;
    end
end
s = quickscale(s);  %normalize the peak to 1

%
% Create a SPIDER trace for a Gaussian pulse where the bandwidth and 
% relative intensity in the arms of the SPIDER setup are parameters
% in a fit to the averaged multipulse SPIDER trace
%
pw = sqrt(N/(12*pi));  %initial guess for pulse width in fit
consts = [freq_shift delay N];
[Estimates, error] = fminsearch(@(params) spider_fit(params, consts, s), [1 pw]);
x = -N/2:N/2-1;
etg = exp(-x.^2 / (Estimates(2))^2);
sg = spider_trace_unequal_arms(etg, freq_shift, delay, Estimates(1));

%
% Plot the multipluse SPIDER trace with the fitted Gaussian SPIDER trace
%
w = x;
figure;
h = plot(w, s, '-g', w, sg, '--k');
style_plot(gca, h, 'spider')
set(h(2), 'LineWidth', 2)

%Find the peak of the background in the trace.  First, find the bottom of 
% the fringes by finding the minima, then choose the largest from them.
trace_prime = diff(s);
%assume that there should be fewer than N/2 local minima in N points
minima = zeros(N/2,1);
a = 1;
for k = 1:N-2
    if trace_prime(k) < 0 && trace_prime(k+1)>0
        minima(a) = s(k+1);
        a = a+1;
    end
end
peak = max(minima);


fprintf('Fitted pulse width:\t\t%d \n', Estimates(2))
rel_int = min([Estimates(1) 1/Estimates(1)]);
fprintf('Fitted rel. intensity:\t%d \n', rel_int)
% RMS error
rmse = sqrt(mean((s - sg).^2));
fprintf('Fitted RMSE:\t\t\t%d \n\n', rmse)
fprintf('Peak of the background:\t%d%%\n\n', peak*100);